%-------------------------------------------------------------------------%
% Copyright (c) 2018 Modenese L.                                          %
%                                                                         %
% Licensed under the Apache License, Version 2.0 (the "License");         %
% you may not use this file except in compliance with the License.        %
% You may obtain a copy of the License at                                 %
% http://www.apache.org/licenses/LICENSE-2.0.                             %
%                                                                         % 
% Unless required by applicable law or agreed to in writing, software     %
% distributed under the License is distributed on an "AS IS" BASIS,       %
% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or         %
% implied. See the License for the specific language governing            %
% permissions and limitations under the License.                          %
%                                                                         %
%    Author:   Luca Modenese, May 2016                                    %
%    email:    l.modenese@sheffield.ac.uk                                 % 
% ----------------------------------------------------------------------- %
%
% This function allows, given a TransformAxis of a SpatialTransform, to 
% change the direction of its axis and set it equal to upd_axis_double.
%
% Inputs:
%    - OS_TransfAxis: an openSim object of class TransformAxis.
%    - upd_axis_double: a Matlab vector (double) specifying an axis versor
%                       to assign to the TransformAxis.
%
% Outputs:
%    - updTransfAxis: an openSim TransformAxis with updated axis.
%--------------------------------------------------------------------------
% last modified: 25/04/2018, Luca Modenese
% Added comments.
%--------------------------------------------------------------------------

function updTransfAxis = updTransformAxis(OS_TransfAxis, upd_axis_double)

% importing libraries
import org.opensim.modeling.*

% changing variable
upd_axis = upd_axis_double;

% update the axis with the rotated values
upd_axis_v = Vec3;
upd_axis_v.set(0,upd_axis(1))
upd_axis_v.set(1,upd_axis(2))
upd_axis_v.set(2,upd_axis(3))

% update axis
OS_TransfAxis.setAxis(upd_axis_v);
updTransfAxis = OS_TransfAxis;

end