%-------------------------------------------------------------------------%
% Copyright (c) 2018, Modenese L.                                         %
%                                                                         %
% Licensed under the Apache License, Version 2.0 (the "License");         %
% you may not use this file except in compliance with the License.        %
% You may obtain a copy of the License at                                 %
% http://www.apache.org/licenses/LICENSE-2.0.                             %
%                                                                         % 
% Unless required by applicable law or agreed to in writing, software     %
% distributed under the License is distributed on an "AS IS" BASIS,       %
% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or         %
% implied. See the License for the specific language governing            %
% permissions and limitations under the License.                          %
%                                                                         %
%    Author:   Luca Modenese, 2016                                        %
%    email:    l.modenese@sheffield.ac.uk                                 % 
% ----------------------------------------------------------------------- %
%
% This function reads a landmark cloud written by NMSBuilder and generates
% a Matlab structure with colheaders and data fields.
%
% Inputs:
%    - filename: file name (including path) of a landmark cloud generated
%                by NMSBuilder v1.0.
%
% Outputs:
%    - LandmarkCloud: Matlab structure with two fields:
%                    * "colheaders": cell array containing names of N landmarks in the
%                     NMSBuilder landmark cloud.
%                    * "data": coordinate of the landmarks as a 3xN matrix. 
% ----------------------------------------------------------------------- %
% Last updated 
% 05/04/2016, Erica Montefiori
% updated to NMSBuilder v1.0
% ----------------------------------------------------------------------- %

function LandmarkCloud = readNMSBuilderLandmarkCloud(filename)

% opening the specified file for reading
fid = fopen(filename,'r');
n_L = 1;

% going through each line until the end of the file
while ~feof(fid)
    % extracting current line
    tline = fgetl(fid);
    % skipping line with time stamps (at the moment assuming only one time
    % stamp
    if strcmp(tline, 'Time	0') || strcmp(tline, 'Time 0')
        display('Skipping Time stamp')
        continue
    else
        % using the extracted line as a string to scan for name of the
        % landmark
        %space = char(32) ;
        comma = char(44) ;
        v = split(tline,comma);
        LandmarkCloud.colheaders{n_L} = v(1);%sscanf(tline,['%s%c%s %*s' ]);
        % scanning string for coordinates of the landmarks
%         float(v(2))
        v1=[cell2mat(v(2)) cell2mat(v(3)) cell2mat(v(4))];
        v1=str2num(v1);
        LandmarkCloud.data(1:3,n_L)   = double(v1).';%sscanf(tline,'%*s %*s %f %*s %f %*s %f\n',[1,3])';
        % updating idex of coordinate and colheaders
        n_L = n_L+1;
    end
end
% closing file
fclose(fid);
display([filename, ' content imported successfully.']);

end