%-------------------------------------------------------------------------%
% Copyright (c) 2016 Modenese L.                                          %
%                                                                         %
% Licensed under the Apache License, Version 2.0 (the "License");         %
% you may not use this file except in compliance with the License.        %
% You may obtain a copy of the License at                                 %
% http://www.apache.org/licenses/LICENSE-2.0.                             %
%                                                                         % 
% Unless required by applicable law or agreed to in writing, software     %
% distributed under the License is distributed on an "AS IS" BASIS,       %
% WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or         %
% implied. See the License for the specific language governing            %
% permissions and limitations under the License.                          %
%                                                                         %
%    Author:   Luca Modenese, May 2016                                    %
%    email:    l.modenese@sheffield.ac.uk                                 % 
% ----------------------------------------------------------------------- %
% This function takes as input a point [x y z] and a landmark cloud [N x 3]
% and returns the point from the cloud that is the closest to given point.
% It also returns the distance between the two points (minimum distance).
% Last updated: 11/05/2016
function [closestPoint, min_dist] = getClosestPoint(point, pointCloud)

    function v = checkDimensions(v)
        % checks dimensionality
        if size(v,2)~=3
            if size(v,1)==3
                warndlg('dimensional check before searching for closest point on landmark cloud cannot be performed because only 3 points are present in the surface.');
            else
                v = v';
            end
        end
    end

% check dimensions and arrangement of vectors
point = checkDimensions(point);
pointCloud = checkDimensions(pointCloud);

% create a [N_point x 3]matrix with the coordinates of the point as rows
point_mat = ones(size(pointCloud,1),1)*point;

% calculate distance from all points of the cloud
dist = (sum((pointCloud-point_mat).^2.0, 2)).^0.5;

% get minimum distance
[min_dist, min_dist_ind]  = min(dist);

% extract minimum distance point
closestPoint = pointCloud(min_dist_ind,:);
end